package com.zanxiang.game.module.manage.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.zanxiang.erp.security.annotation.PreAuthorize;
import com.zanxiang.game.module.manage.pojo.params.GameAuthAddParam;
import com.zanxiang.game.module.manage.pojo.params.GameAuthListParam;
import com.zanxiang.game.module.manage.pojo.params.GameAuthUpdateParam;
import com.zanxiang.game.module.manage.pojo.vo.GameAuthVO;
import com.zanxiang.game.module.manage.service.IGameAuthService;
import com.zanxiang.module.util.pojo.ResultVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * @author : lingfeng
 * @time : 2023-08-17
 * @description : 游戏授权
 */
@Api(tags = {"游戏授权接口"})
@RestController
@RequestMapping("/game/auth")
@Slf4j
public class GameAuthController {

    @Autowired
    private IGameAuthService gameAuthService;

    @ApiOperation(value = "新增用户授权")
    @PostMapping(value = "/add")
    @PreAuthorize(permissionKey = "manage:gameAuth:add")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = Boolean.class)})
    public ResultVO<Boolean> gameAuthAdd(@Validated @RequestBody GameAuthAddParam param) {
        return ResultVO.ok(gameAuthService.gameAuthAdd(param));
    }

    @ApiOperation(value = "更新用户授权")
    @PostMapping(value = "/update")
    @PreAuthorize(permissionKey = "manage:gameAuth:update")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = Boolean.class)})
    public ResultVO<Boolean> gameAuthAdd(@Validated @RequestBody GameAuthUpdateParam param) {
        return ResultVO.ok(gameAuthService.gameAuthUpdate(param));
    }

    @ApiOperation(value = "游戏授权用户列表")
    @PostMapping(value = "/list")
    @PreAuthorize(permissionKey = "manage:gameAuth:list")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = GameAuthVO.class)})
    public ResultVO<IPage<GameAuthVO>> listOfPage(@Validated @RequestBody GameAuthListParam param) {
        return ResultVO.ok(gameAuthService.listOfPage(param));
    }

    @ApiOperation(value = "游戏授权用户删除")
    @DeleteMapping(value = "/delete")
    @PreAuthorize(permissionKey = "manage:gameServer:delete")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = Boolean.class)})
    public ResultVO<Boolean> deleteById(@RequestParam Long id) {
        return ResultVO.ok(gameAuthService.deleteById(id));
    }
}
